---
title: "visualize-study-design"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{visualize-study-design}
  %\VignetteEncoding{UTF-8}
  %\VignetteEngine{knitr::rmarkdown}
editor_options: 
  chunk_output_type: console
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 8,
  fig.height = 6
  
)
```

```{r setup}
library(rwicc)

```

This vignette demos the study design.

```{r}

set.seed(16); 
simulate_interval_censoring(
    study_cohort_size = 2, 
    years_in_study = 10, 
    probability_of_ever_seroconverting = 1) |> 
    plot_censoring_data(
      included_IDs = 1:2,
      labelled_IDs = 1,
      s_vjust = -1,
      xmax = lubridate::ymd("2003-01-01")
    ) |> 
    print()

```

