% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/seroconversion_survival_function.R
\name{seroconversion_cumhaz_function}
\alias{seroconversion_cumhaz_function}
\title{Seroconversion cumulative hazard function}
\usage{
seroconversion_cumhaz_function(t, intercept, slope, entry_time = 0)
}
\arguments{
\item{t}{numeric vector of times since study start (years)}

\item{intercept}{hazard at study start}

\item{slope}{change in hazard per year}

\item{entry_time}{time of study entry; the hazard is zero before this}
}
\value{
a numeric vector of cumulative hazard values
}
\description{
Cumulative hazard obtained by integrating \code{\link[=seroconversion_hazard_function]{seroconversion_hazard_function()}}.
}
\keyword{internal}
